@@ -46,8 +46,6 @@
 #' k$model
 #'
 #' }
-#' 
-#' @importFrom shiny isRunning
 #'
 #' @family variable selection procedures
 #'
@@ -159,9 +157,7 @@ blr_step_aic_forward.default <- function(model, details = FALSE, ...) {
     cat("Variables Entered:", "\n\n")
   }
 
-  if (isRunning()) {
-    cat(paste("-", dplyr::last(preds)), "\n")
-  } else if (interactive()) {
+  if (interactive()) {
     cat(crayon::green(clisymbols::symbol$tick), crayon::bold(dplyr::last(preds)), "\n")
   } else {
     cat(paste("-", dplyr::last(preds)), "\n")
@@ -241,9 +237,7 @@ blr_step_aic_forward.default <- function(model, details = FALSE, ...) {
       step     <- step + 1
 
      
-      if (isRunning()) {
-        cat(paste("-", dplyr::last(preds)), "\n")
-      } else if (interactive()) {
+      if (interactive()) {
         cat(crayon::green(clisymbols::symbol$tick), crayon::bold(dplyr::last(preds)), "\n")
       } else {
         cat(paste("-", dplyr::last(preds)), "\n")
@@ -259,9 +253,7 @@ blr_step_aic_forward.default <- function(model, details = FALSE, ...) {
     cat("\n\n")
     cat("Variables Entered:", "\n\n")
     for (i in seq_len(length(preds))) {
-      if (isRunning()) {
-        cat(paste("-", preds[i]), "\n")
-      } else if (interactive()) {
+      if (interactive()) {
         cat(crayon::green(clisymbols::symbol$tick), crayon::bold(preds[i]), "\n")
       } else {
         cat(paste("-", preds[i]), "\n")
