@@ -118,15 +118,8 @@ blr_step_p_backward.default <- function(model, prem = 0.3, details = FALSE, ...)
         aic    <- c(aic, mfs$m_aic)
         bic    <- c(bic, mfs$m_bic)
         dev    <- c(dev, mfs$m_deviance)
-        # fr     <- ols_regress(paste(response, "~",
-        #                         paste(preds, collapse = " + ")), l)
-        # aic    <- c(aic, ols_aic(fr$model))
-        # bic    <- c(sbc, ols_sbc(fr$model))
-        # dev    <- c(sbic, ols_sbic(fr$model, model))
 
-        if (isRunning()) {
-        cat(paste("-", dplyr::last(rpred), "added"), "\n")
-        } else if (interactive()) {
+        if (interactive()) {
           cat(crayon::red(clisymbols::symbol$cross), crayon::bold(dplyr::last(rpred)), "\n")
         } else {
           cat(paste("-", dplyr::last(rpred)), "\n")
@@ -152,9 +145,7 @@ blr_step_p_backward.default <- function(model, prem = 0.3, details = FALSE, ...)
     cat("\n\n")
     cat("Variables Removed:", "\n\n")
     for (i in seq_len(length(rpred))) {
-      if (isRunning()) {
-        cat(paste("-", rpred[i], "added"), "\n")
-      } else if (interactive()) {
+      if (interactive()) {
         cat(crayon::red(clisymbols::symbol$cross), crayon::bold(rpred[i]), "\n")
       } else {
         cat(paste("-", rpred[i]), "\n")
