@@ -21,10 +21,15 @@
 
   tip <- sample(tips, 1)
   
-  if (behind_cran) {
-    packageStartupMessage("A new version of blorr (0.2.0) is available with bug fixes and new features.")
-  } else {
-    packageStartupMessage(paste(strwrap(tip), collapse = "\n"))
-  }   
-  
+  if (interactive()) {
+    if (behind_cran) {
+      msg <- "A new version of blorr is available with bug fixes and new features."
+      packageStartupMessage(msg, "\nWould you like to install it?")
+      if (utils::menu(c("Yes", "No")) == 1) {
+        utils::update.packages("blorr")
+      } 
+    } else {
+      packageStartupMessage(paste(strwrap(tip), collapse = "\n"))
+    }   
+  } 
 }
